dag_cbor.encoding.err
=====================

.. automodule:: dag_cbor.encoding.err

CBOREncodingError
-----------------

.. autoclass:: dag_cbor.encoding.err.CBOREncodingError
    :show-inheritance:
    :members:

CBORError
---------

.. autoclass:: dag_cbor.encoding.err.CBORError
    :show-inheritance:
    :members:

DAGCBOREncodingError
--------------------

.. autoclass:: dag_cbor.encoding.err.DAGCBOREncodingError
    :show-inheritance:
    :members:

DAGCBORError
------------

.. autoclass:: dag_cbor.encoding.err.DAGCBORError
    :show-inheritance:
    :members:
